puzzlepiece module
==================

The main module contains convenience references to the :class:`puzzlepiece.puzzle.Puzzle`, :class:`puzzlepiece.piece.Piece`,
and :any:`puzzlepiece.puzzle.QApp` objects,
so they can be directly referenced as `puzzlepiece.Puzzle`, `puzzlepiece.Piece`, and `puzzlepiece.QApp`.

Importing it also gives direct access to:
  * :mod:`puzzlepiece.param`
  * :mod:`puzzlepiece.action`
  * :mod:`puzzlepiece.parse`
  * :mod:`puzzlepiece.threads`